@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2003-2017 Free Software Foundation, Inc.
+# Copyright (C) 2003-2024 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 # Test to make sure that adding a new directory works, even from
 # subdirectories.  The sister test 'subdir-add-pr46.sh' makes sure
@@ -32,11 +32,15 @@ echo 'AC_CONFIG_FILES([sub/Makefile])' > confiles.m4
 
 cat > Makefile.am << 'END'
 SUBDIRS = sub
+
+# The test can fail under a parallel make, so disable.
+# No evident way to debug or reliably reproduce.
+.NOTPARALLEL:
 END
 
 mkdir sub
 
-: > sub/Makefile.am
+echo .NOTPARALLEL: >sub/Makefile.am
 
 mkdir m4
 echo 'AC_DEFUN([MORE_DEFS], [])' > m4/moredefs.m4
@@ -53,7 +57,7 @@ $MAKE
 # configure.ac.  That is already tested by 'subdir-add-pr46.sh' though,
 # so here we try to just edit a file that is included by configure.ac,
 # without touching configure.ac itself.
-
+$sleep
 mkdir sub/maude
 cat > sub/maude/Makefile.am << 'END'
 include_HEADERS = foo.h
@@ -76,6 +80,7 @@ echo 'AC_CONFIG_FILES([maude/Makefile sub/maude/Makefile])' >> confiles.m4
 # We want a simple rebuild from sub/ to create sub/maude/Makefile
 # and maude/Makefile automatically.
 cd sub
+$sleep
 $MAKE
 cd ..
 grep '^SUBDIRS = *maude *$' sub/Makefile.in
@@ -85,6 +90,7 @@ test -f sub/maude/Makefile
 
 # Make sure the dependencies of aclocal.m4 or honored at least from
 # the top-level directory.
+$sleep
 echo 'AC_DEFUN([MORE_DEFS], [AC_SUBST([GREPME])])' > m4/moredefs.m4
 $MAKE
 
