@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2011-2017 Free Software Foundation, Inc.
+# Copyright (C) 2011-2024 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 # GNU General Public License for more details.
 #
 # You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
+# along with this program.  If not, see <https://www.gnu.org/licenses/>.
 
 # Custom test drivers: if a log file has a directory component (as in
 # e.g., 'sub/foo.log'), the Automake test harness must ensure that
@@ -42,6 +42,13 @@ check-local: $(TEST_SUITE_LOG)
 	test -f sub/foo.trs
 	test -f sub/subsub/bar.trs
 	test -f sub1/baz.trs
+
+# Tell GNU make not to parallelize, since the two tests under sub/
+# can result in, for example:
+#   fatal: making test-suite.log: failed to create sub/foo.trs
+#   fatal: making test-suite.log: failed to create sub/foo.log
+# No evident way to debug or reliably reproduce.
+.NOTPARALLEL:
 END
 
 echo "#!$AM_TEST_RUNNER_SHELL" > checkdir-driver
