@@ -1,5 +1,5 @@
 #! /bin/sh
-# Copyright (C) 2002-2018 Free Software Foundation, Inc.
+# Copyright (C) 2002-2024 Free Software Foundation, Inc.
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -57,4 +57,9 @@ $MAKE distcheck
 test -f ../subdir/main.info
 test ! -e subdir/main.info
 
+# Make sure automatic -I flags were added for the subdir.
+grep '\$(MAKEINFO).* -I subdir ' ../Makefile.in
+grep '\$(TEXI2DVI).* -I subdir ' ../Makefile.in
+grep '\$(TEXI2PDF).* -I subdir ' ../Makefile.in
+
 :
